@@ -199,7 +199,11 @@ class Dashboard:
         return contents
     
     def map_alias_to_fmo(self, alias, fmo):
-        assert isinstance(alias, str), 'alias must be string e.g. "3", "99", "-99"'
+        '''
+        alias must be string e.g. "3", "99", "-99"
+        '''
+        if not isinstance(alias, str):
+            return None
         fmo_alias_mapping = self.df_brackets.set_index('alias').fmo.to_dict()
         if alias != '99':
             fmo = fmo_alias_mapping.get(alias, None)
